#!/bin/bash

# Vendor and Device IDs
VENDOR_ID="10c4"
DEVICE_ID="ea60"

# Run lsusb to list USB devices and grep for the vendor and device IDs
USB_INFO=$(lsusb | grep "$VENDOR_ID:$DEVICE_ID")

# Extract the bus and device numbers for each device
BUS_LIST=($(echo "$USB_INFO" | awk '{print $2}'))
DEVICE_LIST=($(echo "$USB_INFO" | awk '{print $4}' | tr -d ':'))

# Initialize counter for environment variable names
#count=0

# Iterate over each device
for ((i = 0; i < ${#BUS_LIST[@]}; i++)); do
    BUS=${BUS_LIST[$i]}
    DEVICE=${DEVICE_LIST[$i]}
    
    # Use udevadm to find the device path
    DEVICE_PATH=$(udevadm info --query=path --name=/dev/bus/usb/$BUS/$DEVICE)

    # Find ttyUSB port by checking /sys/class/tty
    TTYUSB_PORT=$(ls -l /sys/class/tty/ | grep usb | grep -o "ttyUSB[0-9]*" | while read -r line; do
        if [ -e "/sys/class/tty/$line/device" ]; then
            DEV_PATH=$(readlink -f /sys/class/tty/$line/device)
            if [[ $DEV_PATH == *"$DEVICE_PATH"* ]]; then
                echo $line
                break
            fi
        fi
    done)
    # Run logger command line utility with the current USB port
    sudo chmod 666 /dev/$TTYUSB_PORT
    sudo chmod +x Syslog-SKU-091-3x
    echo "Calling logger with /dev/$TTYUSB_PORT"
    output=$(./Syslog-SKU-091-3x port /dev/$TTYUSB_PORT)
    echo "Output is $output"
    
    # Check if the '@' character is present in the output
    if [[ $output == *'@'* ]]; then
        # Create and export the ttyUSB port as a global environment variable
        #ttyUSB_variable="TTYUSB_PORT$count"
        ttyUSB_variable="TTYUSB_PORT"
        ttyUSB_value="/dev/$TTYUSB_PORT"
        declare "$ttyUSB_variable=$ttyUSB_value"

        # Below: exporting ttyUSB_variable for current terminal session
        export "$ttyUSB_variable"  
        
        # Bbelow: exporting ttyUSB_variable system wide, for newly opened terminal session 
        # for current user  
        echo "export ttyUSB_value=\"$ttyUSB_value\"" >> ~/.bashrc
        
        # Below: is the same for every user (currently commented out)
        # If necessary can be uncommented
        #echo "export ttyUSB_value=\"$ttyUSB_value\"" | sudo tee -a /etc/profile
        
        echo "Exported $ttyUSB_variable with value $ttyUSB_value"
    fi

    # Increment counter
    #((count++))
done
